
# Type: has unit


connects a quantity value to a unit

URI: [biolink:has_unit](https://w3id.org/biolink/vocab/has_unit)


## Domain and Range

[QuantityValue](QuantityValue.md) ->  <sub>OPT</sub> [Unit](types/Unit.md)

## Parents


## Children


## Used by

 * [QuantityValue](QuantityValue.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | qud:unit |
| **In Subsets:** | | samples |

